Class: Google::Apis::AnalyticsdataV1beta::FilterExpression

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsdata_v1beta/classes.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb

Overview

To express dimension or metric filters. The fields in the same FilterExpression need to be either all dimensions or all metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FilterExpression

Returns a new instance of FilterExpression.



976
977
978
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 976

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#and_groupGoogle::Apis::AnalyticsdataV1beta::FilterExpressionList

A list of filter expressions. Corresponds to the JSON property andGroup



958
959
960
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 958

def and_group
  @and_group
end

#filterGoogle::Apis::AnalyticsdataV1beta::Filter

An expression to filter dimension or metric values. Corresponds to the JSON property filter



963
964
965
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 963

def filter
  @filter
end

#not_expressionGoogle::Apis::AnalyticsdataV1beta::FilterExpression

To express dimension or metric filters. The fields in the same FilterExpression need to be either all dimensions or all metrics. Corresponds to the JSON property notExpression



969
970
971
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 969

def not_expression
  @not_expression
end

#or_groupGoogle::Apis::AnalyticsdataV1beta::FilterExpressionList

A list of filter expressions. Corresponds to the JSON property orGroup



974
975
976
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 974

def or_group
  @or_group
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



981
982
983
984
985
986
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 981

def update!(**args)
  @and_group = args[:and_group] if args.key?(:and_group)
  @filter = args[:filter] if args.key?(:filter)
  @not_expression = args[:not_expression] if args.key?(:not_expression)
  @or_group = args[:or_group] if args.key?(:or_group)
end