Class: Google::Apis::AnalyticsdataV1beta::MetricMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsdata_v1beta/classes.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb

Overview

Explains a metric.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MetricMetadata

Returns a new instance of MetricMetadata.



1264
1265
1266
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1264

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_nameString

A metric name. Useable in Metric's name. For example, eventCount . Corresponds to the JSON property apiName

Returns:

  • (String)


1209
1210
1211
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1209

def api_name
  @api_name
end

#blocked_reasonsArray<String>

If reasons are specified, your access is blocked to this metric for this property. API requests from you to this property for this metric will succeed; however, the report will contain only zeros for this metric. API requests with metric filters on blocked metrics will fail. If reasons are empty, you have access to this metric. To learn more, see Access and data-restriction management. Corresponds to the JSON property blockedReasons

Returns:

  • (Array<String>)


1219
1220
1221
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1219

def blocked_reasons
  @blocked_reasons
end

#categoryString

The display name of the category that this metrics belongs to. Similar dimensions and metrics are categorized together. Corresponds to the JSON property category

Returns:

  • (String)


1225
1226
1227
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1225

def category
  @category
end

#custom_definitionBoolean Also known as: custom_definition?

True if the metric is a custom metric for this property. Corresponds to the JSON property customDefinition

Returns:

  • (Boolean)


1230
1231
1232
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1230

def custom_definition
  @custom_definition
end

#deprecated_api_namesArray<String>

Still usable but deprecated names for this metric. If populated, this metric is available by either apiName or one of deprecatedApiNames for a period of time. After the deprecation period, the metric will be available only by apiName. Corresponds to the JSON property deprecatedApiNames

Returns:

  • (Array<String>)


1239
1240
1241
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1239

def deprecated_api_names
  @deprecated_api_names
end

#descriptionString

Description of how this metric is used and calculated. Corresponds to the JSON property description

Returns:

  • (String)


1244
1245
1246
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1244

def description
  @description
end

#expressionString

The mathematical expression for this derived metric. Can be used in Metric's expression field for equivalent reports. Most metrics are not expressions, and for non-expressions, this field is empty. Corresponds to the JSON property expression

Returns:

  • (String)


1251
1252
1253
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1251

def expression
  @expression
end

#typeString

The type of this metric. Corresponds to the JSON property type

Returns:

  • (String)


1256
1257
1258
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1256

def type
  @type
end

#ui_nameString

This metric's name within the Google Analytics user interface. For example, Event count. Corresponds to the JSON property uiName

Returns:

  • (String)


1262
1263
1264
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1262

def ui_name
  @ui_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1269
1270
1271
1272
1273
1274
1275
1276
1277
1278
1279
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1269

def update!(**args)
  @api_name = args[:api_name] if args.key?(:api_name)
  @blocked_reasons = args[:blocked_reasons] if args.key?(:blocked_reasons)
  @category = args[:category] if args.key?(:category)
  @custom_definition = args[:custom_definition] if args.key?(:custom_definition)
  @deprecated_api_names = args[:deprecated_api_names] if args.key?(:deprecated_api_names)
  @description = args[:description] if args.key?(:description)
  @expression = args[:expression] if args.key?(:expression)
  @type = args[:type] if args.key?(:type)
  @ui_name = args[:ui_name] if args.key?(:ui_name)
end