Class: Google::Apis::AnalyticsdataV1beta::PivotHeader

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsdata_v1beta/classes.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb

Overview

Dimensions' values in a single pivot.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PivotHeader

Returns a new instance of PivotHeader.



1610
1611
1612
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pivot_dimension_headersArray<Google::Apis::AnalyticsdataV1beta::PivotDimensionHeader>

The size is the same as the cardinality of the corresponding dimension combinations. Corresponds to the JSON property pivotDimensionHeaders



1601
1602
1603
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1601

def pivot_dimension_headers
  @pivot_dimension_headers
end

#row_countFixnum

The cardinality of the pivot. The total number of rows for this pivot's fields regardless of how the parameters offset and limit are specified in the request. Corresponds to the JSON property rowCount

Returns:

  • (Fixnum)


1608
1609
1610
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1608

def row_count
  @row_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1615
1616
1617
1618
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1615

def update!(**args)
  @pivot_dimension_headers = args[:pivot_dimension_headers] if args.key?(:pivot_dimension_headers)
  @row_count = args[:row_count] if args.key?(:row_count)
end