Class: Google::Apis::AnalyticsdataV1beta::PivotOrderBy
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticsdataV1beta::PivotOrderBy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticsdata_v1beta/classes.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb
Overview
Sorts by a pivot column group.
Instance Attribute Summary collapse
-
#metric_name ⇒ String
In the response to order by, order rows by this column.
-
#pivot_selections ⇒ Array<Google::Apis::AnalyticsdataV1beta::PivotSelection>
Used to select a dimension name and value pivot.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PivotOrderBy
constructor
A new instance of PivotOrderBy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PivotOrderBy
Returns a new instance of PivotOrderBy.
1638 1639 1640 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1638 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metric_name ⇒ String
In the response to order by, order rows by this column. Must be a metric name
from the request.
Corresponds to the JSON property metricName
1629 1630 1631 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1629 def metric_name @metric_name end |
#pivot_selections ⇒ Array<Google::Apis::AnalyticsdataV1beta::PivotSelection>
Used to select a dimension name and value pivot. If multiple pivot selections
are given, the sort occurs on rows where all pivot selection dimension name
and value pairs match the row's dimension name and value pair.
Corresponds to the JSON property pivotSelections
1636 1637 1638 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1636 def pivot_selections @pivot_selections end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1643 1644 1645 1646 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1643 def update!(**args) @metric_name = args[:metric_name] if args.key?(:metric_name) @pivot_selections = args[:pivot_selections] if args.key?(:pivot_selections) end |