Class: Google::Apis::AnalyticsdataV1beta::PropertyQuota

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsdata_v1beta/classes.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb

Overview

Current state of all quotas for this Analytics Property. If any quota for a property is exhausted, all requests to that property will return Resource Exhausted errors.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PropertyQuota

Returns a new instance of PropertyQuota.



1719
1720
1721
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1719

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#concurrent_requestsGoogle::Apis::AnalyticsdataV1beta::QuotaStatus

Current state for a particular quota group. Corresponds to the JSON property concurrentRequests



1692
1693
1694
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1692

def concurrent_requests
  @concurrent_requests
end

#potentially_thresholded_requests_per_hourGoogle::Apis::AnalyticsdataV1beta::QuotaStatus

Current state for a particular quota group. Corresponds to the JSON property potentiallyThresholdedRequestsPerHour



1697
1698
1699
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1697

def potentially_thresholded_requests_per_hour
  @potentially_thresholded_requests_per_hour
end

#server_errors_per_project_per_hourGoogle::Apis::AnalyticsdataV1beta::QuotaStatus

Current state for a particular quota group. Corresponds to the JSON property serverErrorsPerProjectPerHour



1702
1703
1704
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1702

def server_errors_per_project_per_hour
  @server_errors_per_project_per_hour
end

#tokens_per_dayGoogle::Apis::AnalyticsdataV1beta::QuotaStatus

Current state for a particular quota group. Corresponds to the JSON property tokensPerDay



1707
1708
1709
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1707

def tokens_per_day
  @tokens_per_day
end

#tokens_per_hourGoogle::Apis::AnalyticsdataV1beta::QuotaStatus

Current state for a particular quota group. Corresponds to the JSON property tokensPerHour



1712
1713
1714
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1712

def tokens_per_hour
  @tokens_per_hour
end

#tokens_per_project_per_hourGoogle::Apis::AnalyticsdataV1beta::QuotaStatus

Current state for a particular quota group. Corresponds to the JSON property tokensPerProjectPerHour



1717
1718
1719
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1717

def tokens_per_project_per_hour
  @tokens_per_project_per_hour
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1724
1725
1726
1727
1728
1729
1730
1731
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1724

def update!(**args)
  @concurrent_requests = args[:concurrent_requests] if args.key?(:concurrent_requests)
  @potentially_thresholded_requests_per_hour = args[:potentially_thresholded_requests_per_hour] if args.key?(:potentially_thresholded_requests_per_hour)
  @server_errors_per_project_per_hour = args[:server_errors_per_project_per_hour] if args.key?(:server_errors_per_project_per_hour)
  @tokens_per_day = args[:tokens_per_day] if args.key?(:tokens_per_day)
  @tokens_per_hour = args[:tokens_per_hour] if args.key?(:tokens_per_hour)
  @tokens_per_project_per_hour = args[:tokens_per_project_per_hour] if args.key?(:tokens_per_project_per_hour)
end