Class: Google::Apis::AnalyticsdataV1beta::QueryAudienceExportRequest
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticsdataV1beta::QueryAudienceExportRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticsdata_v1beta/classes.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb
Overview
A request to list users in an audience export.
Instance Attribute Summary collapse
-
#limit ⇒ Fixnum
Optional.
-
#offset ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryAudienceExportRequest
constructor
A new instance of QueryAudienceExportRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryAudienceExportRequest
Returns a new instance of QueryAudienceExportRequest.
1760 1761 1762 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#limit ⇒ Fixnum
Optional. The number of rows to return. If unspecified, 10,000 rows are
returned. The API returns a maximum of 250,000 rows per request, no matter how
many you ask for. limit must be positive. The API can also return fewer rows
than the requested limit, if there aren't as many dimension values as the
limit. To learn more about this pagination parameter, see Pagination
.
Corresponds to the JSON property limit
1747 1748 1749 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1747 def limit @limit end |
#offset ⇒ Fixnum
Optional. The row count of the start row. The first row is counted as row 0.
When paging, the first request does not specify offset; or equivalently, sets
offset to 0; the first request returns the first limit of rows. The second
request sets offset to the limit of the first request; the second request
returns the second limit of rows. To learn more about this pagination
parameter, see Pagination.
Corresponds to the JSON property offset
1758 1759 1760 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1758 def offset @offset end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1765 1766 1767 1768 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1765 def update!(**args) @limit = args[:limit] if args.key?(:limit) @offset = args[:offset] if args.key?(:offset) end |