Class: Google::Apis::AnalyticsdataV1beta::QueryAudienceExportResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsdata_v1beta/classes.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb

Overview

A list of users in an audience export.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryAudienceExportResponse

Returns a new instance of QueryAudienceExportResponse.



1799
1800
1801
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1799

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audience_exportGoogle::Apis::AnalyticsdataV1beta::AudienceExport

An audience export is a list of users in an audience at the time of the list's creation. One audience may have multiple audience exports created for different days. Corresponds to the JSON property audienceExport



1780
1781
1782
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1780

def audience_export
  @audience_export
end

#audience_rowsArray<Google::Apis::AnalyticsdataV1beta::V1betaAudienceRow>

Rows for each user in an audience export. The number of rows in this response will be less than or equal to request's page size. Corresponds to the JSON property audienceRows



1786
1787
1788
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1786

def audience_rows
  @audience_rows
end

#row_countFixnum

The total number of rows in the AudienceExport result. rowCount is independent of the number of rows returned in the response, the limit request parameter, and the offset request parameter. For example if a query returns 175 rows and includes limit of 50 in the API request, the response will contain rowCount of 175 but only 50 rows. To learn more about this pagination parameter, see Pagination. Corresponds to the JSON property rowCount

Returns:

  • (Fixnum)


1797
1798
1799
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1797

def row_count
  @row_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1804
1805
1806
1807
1808
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1804

def update!(**args)
  @audience_export = args[:audience_export] if args.key?(:audience_export)
  @audience_rows = args[:audience_rows] if args.key?(:audience_rows)
  @row_count = args[:row_count] if args.key?(:row_count)
end