Class: Google::Apis::AnalyticsdataV1beta::ResponseMetaData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsdata_v1beta/classes.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb

Overview

Response's metadata carrying additional information about the report content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResponseMetaData

Returns a new instance of ResponseMetaData.



1908
1909
1910
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#currency_codeString

The currency code used in this report. Intended to be used in formatting currency metrics like purchaseRevenue for visualization. If currency_code was specified in the request, this response parameter will echo the request parameter; otherwise, this response parameter is the property's current currency_code. Currency codes are string encodings of currency types from the ISO 4217 standard (https://en.wikipedia.org/wiki/ISO_4217); for example "USD", "EUR", "JPY". To learn more, see https://support.google.com/analytics/answer/ 9796179. Corresponds to the JSON property currencyCode

Returns:

  • (String)


1850
1851
1852
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1850

def currency_code
  @currency_code
end

#data_loss_from_other_rowBoolean Also known as: data_loss_from_other_row?

If true, indicates some buckets of dimension combinations are rolled into "( other)" row. This can happen for high cardinality reports. The metadata parameter dataLossFromOtherRow is populated based on the aggregated data table used in the report. The parameter will be accurately populated regardless of the filters and limits in the report. For example, the (other) row could be dropped from the report because the request contains a filter on sessionSource = google. This parameter will still be populated if data loss from other row was present in the input aggregate data used to generate this report. To learn more, see About the (other) row and data sampling. Corresponds to the JSON property dataLossFromOtherRow

Returns:

  • (Boolean)


1864
1865
1866
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1864

def data_loss_from_other_row
  @data_loss_from_other_row
end

#empty_reasonString

If empty reason is specified, the report is empty for this reason. Corresponds to the JSON property emptyReason

Returns:

  • (String)


1870
1871
1872
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1870

def empty_reason
  @empty_reason
end

#sampling_metadatasArray<Google::Apis::AnalyticsdataV1beta::SamplingMetadata>

If this report results is sampled, this describes the percentage of events used in this report. One samplingMetadatas is populated for each date range. Each samplingMetadatas corresponds to a date range in order that date ranges were specified in the request. However if the results are not sampled, this field will not be defined. Corresponds to the JSON property samplingMetadatas



1880
1881
1882
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1880

def sampling_metadatas
  @sampling_metadatas
end

#schema_restriction_responseGoogle::Apis::AnalyticsdataV1beta::SchemaRestrictionResponse

The schema restrictions actively enforced in creating this report. To learn more, see Access and data-restriction management. Corresponds to the JSON property schemaRestrictionResponse



1887
1888
1889
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1887

def schema_restriction_response
  @schema_restriction_response
end

#subject_to_thresholdingBoolean Also known as: subject_to_thresholding?

If subjectToThresholding is true, this report is subject to thresholding and only returns data that meets the minimum aggregation thresholds. It is possible for a request to be subject to thresholding thresholding and no data is absent from the report, and this happens when all data is above the thresholds. To learn more, see Data thresholds. Corresponds to the JSON property subjectToThresholding

Returns:

  • (Boolean)


1897
1898
1899
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1897

def subject_to_thresholding
  @subject_to_thresholding
end

#time_zoneString

The property's current timezone. Intended to be used to interpret time-based dimensions like hour and minute. Formatted as strings from the IANA Time Zone database (https://www.iana.org/time-zones); for example "America/New_York" or "Asia/Tokyo". Corresponds to the JSON property timeZone

Returns:

  • (String)


1906
1907
1908
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1906

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1913
1914
1915
1916
1917
1918
1919
1920
1921
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1913

def update!(**args)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @data_loss_from_other_row = args[:data_loss_from_other_row] if args.key?(:data_loss_from_other_row)
  @empty_reason = args[:empty_reason] if args.key?(:empty_reason)
  @sampling_metadatas = args[:sampling_metadatas] if args.key?(:sampling_metadatas)
  @schema_restriction_response = args[:schema_restriction_response] if args.key?(:schema_restriction_response)
  @subject_to_thresholding = args[:subject_to_thresholding] if args.key?(:subject_to_thresholding)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end