Class: Google::Apis::AnalyticsdataV1beta::RunPivotReportRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsdata_v1beta/classes.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb

Overview

The request to generate a pivot report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunPivotReportRequest

Returns a new instance of RunPivotReportRequest.



2059
2060
2061
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cohort_specGoogle::Apis::AnalyticsdataV1beta::CohortSpec

The specification of cohorts for a cohort report. Cohort reports create a time series of user retention for the cohort. For example, you could select the cohort of users that were acquired in the first week of September and follow that cohort for the next six weeks. Selecting the users acquired in the first week of September cohort is specified in the cohort object. Following that cohort for the next six weeks is specified in the cohortsRange object. For examples, see Cohort Report Examples. The report response could show a weekly time series where say your app has retained 60% of this cohort after three weeks and 25% of this cohort after six weeks. These two percentages can be calculated by the metric cohortActiveUsers/ cohortTotalUsers and will be separate rows in the report. Corresponds to the JSON property cohortSpec



1973
1974
1975
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1973

def cohort_spec
  @cohort_spec
end

#comparisonsArray<Google::Apis::AnalyticsdataV1beta::Comparison>

Optional. The configuration of comparisons requested and displayed. The request requires both a comparisons field and a comparisons dimension to receive a comparison column in the response. Corresponds to the JSON property comparisons



1980
1981
1982
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1980

def comparisons
  @comparisons
end

#currency_codeString

A currency code in ISO4217 format, such as "AED", "USD", "JPY". If the field is empty, the report uses the property's default currency. Corresponds to the JSON property currencyCode

Returns:

  • (String)


1986
1987
1988
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1986

def currency_code
  @currency_code
end

#date_rangesArray<Google::Apis::AnalyticsdataV1beta::DateRange>

The date range to retrieve event data for the report. If multiple date ranges are specified, event data from each date range is used in the report. A special dimension with field name "dateRange" can be included in a Pivot's field names; if included, the report compares between date ranges. In a cohort request, this dateRanges must be unspecified. Corresponds to the JSON property dateRanges



1995
1996
1997
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1995

def date_ranges
  @date_ranges
end

#dimension_filterGoogle::Apis::AnalyticsdataV1beta::FilterExpression

To express dimension or metric filters. The fields in the same FilterExpression need to be either all dimensions or all metrics. Corresponds to the JSON property dimensionFilter



2001
2002
2003
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2001

def dimension_filter
  @dimension_filter
end

#dimensionsArray<Google::Apis::AnalyticsdataV1beta::Dimension>

The dimensions requested. All defined dimensions must be used by one of the following: dimension_expression, dimension_filter, pivots, order_bys. Corresponds to the JSON property dimensions



2007
2008
2009
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2007

def dimensions
  @dimensions
end

#keep_empty_rowsBoolean Also known as: keep_empty_rows?

If false or unspecified, each row with all metrics equal to 0 will not be returned. If true, these rows will be returned if they are not separately removed by a filter. Regardless of this keep_empty_rows setting, only data recorded by the Google Analytics property can be displayed in a report. For example if a property never logs a purchase event, then a query for the eventName dimension and eventCount metric will not have a row eventName: " purchase" and eventCount: 0. Corresponds to the JSON property keepEmptyRows

Returns:

  • (Boolean)


2018
2019
2020
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2018

def keep_empty_rows
  @keep_empty_rows
end

#metric_filterGoogle::Apis::AnalyticsdataV1beta::FilterExpression

To express dimension or metric filters. The fields in the same FilterExpression need to be either all dimensions or all metrics. Corresponds to the JSON property metricFilter



2025
2026
2027
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2025

def metric_filter
  @metric_filter
end

#metricsArray<Google::Apis::AnalyticsdataV1beta::Metric>

The metrics requested, at least one metric needs to be specified. All defined metrics must be used by one of the following: metric_expression, metric_filter, order_bys. Corresponds to the JSON property metrics



2032
2033
2034
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2032

def metrics
  @metrics
end

#pivotsArray<Google::Apis::AnalyticsdataV1beta::Pivot>

Describes the visual format of the report's dimensions in columns or rows. The union of the fieldNames (dimension names) in all pivots must be a subset of dimension names defined in Dimensions. No two pivots can share a dimension. A dimension is only visible if it appears in a pivot. Corresponds to the JSON property pivots



2040
2041
2042
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2040

def pivots
  @pivots
end

#propertyString

A Google Analytics property identifier whose events are tracked. Specified in the URL path and not the body. To learn more, see where to find your Property ID. Within a batch request, this property should either be unspecified or consistent with the batch-level property. Example: properties/ 1234 Corresponds to the JSON property property

Returns:

  • (String)


2050
2051
2052
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2050

def property
  @property
end

#return_property_quotaBoolean Also known as: return_property_quota?

Toggles whether to return the current state of this Google Analytics property' s quota. Quota is returned in PropertyQuota. Corresponds to the JSON property returnPropertyQuota

Returns:

  • (Boolean)


2056
2057
2058
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2056

def return_property_quota
  @return_property_quota
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2064

def update!(**args)
  @cohort_spec = args[:cohort_spec] if args.key?(:cohort_spec)
  @comparisons = args[:comparisons] if args.key?(:comparisons)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @date_ranges = args[:date_ranges] if args.key?(:date_ranges)
  @dimension_filter = args[:dimension_filter] if args.key?(:dimension_filter)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @keep_empty_rows = args[:keep_empty_rows] if args.key?(:keep_empty_rows)
  @metric_filter = args[:metric_filter] if args.key?(:metric_filter)
  @metrics = args[:metrics] if args.key?(:metrics)
  @pivots = args[:pivots] if args.key?(:pivots)
  @property = args[:property] if args.key?(:property)
  @return_property_quota = args[:return_property_quota] if args.key?(:return_property_quota)
end