Class: Google::Apis::AnalyticsdataV1beta::RunPivotReportResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsdata_v1beta/classes.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb

Overview

The response pivot report table corresponding to a pivot request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunPivotReportResponse

Returns a new instance of RunPivotReportResponse.



2140
2141
2142
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2140

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregatesArray<Google::Apis::AnalyticsdataV1beta::Row>

Aggregation of metric values. Can be totals, minimums, or maximums. The returned aggregations are controlled by the metric_aggregations in the pivot. The type of aggregation returned in each row is shown by the dimension_values which are set to "RESERVED_". Corresponds to the JSON property aggregates



2090
2091
2092
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2090

def aggregates
  @aggregates
end

#dimension_headersArray<Google::Apis::AnalyticsdataV1beta::DimensionHeader>

Describes dimension columns. The number of DimensionHeaders and ordering of DimensionHeaders matches the dimensions present in rows. Corresponds to the JSON property dimensionHeaders



2096
2097
2098
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2096

def dimension_headers
  @dimension_headers
end

#kindString

Identifies what kind of resource this message is. This kind is always the fixed string "analyticsData#runPivotReport". Useful to distinguish between response types in JSON. Corresponds to the JSON property kind

Returns:

  • (String)


2103
2104
2105
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2103

def kind
  @kind
end

#metadataGoogle::Apis::AnalyticsdataV1beta::ResponseMetaData

Response's metadata carrying additional information about the report content. Corresponds to the JSON property metadata



2108
2109
2110
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2108

def 
  @metadata
end

#metric_headersArray<Google::Apis::AnalyticsdataV1beta::MetricHeader>

Describes metric columns. The number of MetricHeaders and ordering of MetricHeaders matches the metrics present in rows. Corresponds to the JSON property metricHeaders



2114
2115
2116
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2114

def metric_headers
  @metric_headers
end

#pivot_headersArray<Google::Apis::AnalyticsdataV1beta::PivotHeader>

Summarizes the columns and rows created by a pivot. Each pivot in the request produces one header in the response. If we have a request like this: "pivots": ["fieldNames": ["country", "city"], "fieldNames": "eventName"] We will have the following pivotHeaders in the response: "pivotHeaders" : [" dimensionHeaders": [ "dimensionValues": [ "value": "United Kingdom", " value": "London" ] , "dimensionValues": [ "value": "Japan", "value": "Osaka" ] ], "dimensionHeaders": [ "dimensionValues": ["value": " session_start"] , "dimensionValues": ["value": "scroll"] ]] Corresponds to the JSON property pivotHeaders



2126
2127
2128
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2126

def pivot_headers
  @pivot_headers
end

#property_quotaGoogle::Apis::AnalyticsdataV1beta::PropertyQuota

Current state of all quotas for this Analytics Property. If any quota for a property is exhausted, all requests to that property will return Resource Exhausted errors. Corresponds to the JSON property propertyQuota



2133
2134
2135
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2133

def property_quota
  @property_quota
end

#rowsArray<Google::Apis::AnalyticsdataV1beta::Row>

Rows of dimension value combinations and metric values in the report. Corresponds to the JSON property rows



2138
2139
2140
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2138

def rows
  @rows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2145

def update!(**args)
  @aggregates = args[:aggregates] if args.key?(:aggregates)
  @dimension_headers = args[:dimension_headers] if args.key?(:dimension_headers)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metric_headers = args[:metric_headers] if args.key?(:metric_headers)
  @pivot_headers = args[:pivot_headers] if args.key?(:pivot_headers)
  @property_quota = args[:property_quota] if args.key?(:property_quota)
  @rows = args[:rows] if args.key?(:rows)
end