Class: Google::Apis::AnalyticsdataV1beta::RunRealtimeReportResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsdata_v1beta/classes.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb

Overview

The response realtime report table corresponding to a request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunRealtimeReportResponse

Returns a new instance of RunRealtimeReportResponse.



2297
2298
2299
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2297

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimension_headersArray<Google::Apis::AnalyticsdataV1beta::DimensionHeader>

Describes dimension columns. The number of DimensionHeaders and ordering of DimensionHeaders matches the dimensions present in rows. Corresponds to the JSON property dimensionHeaders



2247
2248
2249
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2247

def dimension_headers
  @dimension_headers
end

#kindString

Identifies what kind of resource this message is. This kind is always the fixed string "analyticsData#runRealtimeReport". Useful to distinguish between response types in JSON. Corresponds to the JSON property kind

Returns:

  • (String)


2254
2255
2256
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2254

def kind
  @kind
end

#maximumsArray<Google::Apis::AnalyticsdataV1beta::Row>

If requested, the maximum values of metrics. Corresponds to the JSON property maximums



2259
2260
2261
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2259

def maximums
  @maximums
end

#metric_headersArray<Google::Apis::AnalyticsdataV1beta::MetricHeader>

Describes metric columns. The number of MetricHeaders and ordering of MetricHeaders matches the metrics present in rows. Corresponds to the JSON property metricHeaders



2265
2266
2267
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2265

def metric_headers
  @metric_headers
end

#minimumsArray<Google::Apis::AnalyticsdataV1beta::Row>

If requested, the minimum values of metrics. Corresponds to the JSON property minimums



2270
2271
2272
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2270

def minimums
  @minimums
end

#property_quotaGoogle::Apis::AnalyticsdataV1beta::PropertyQuota

Current state of all quotas for this Analytics Property. If any quota for a property is exhausted, all requests to that property will return Resource Exhausted errors. Corresponds to the JSON property propertyQuota



2277
2278
2279
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2277

def property_quota
  @property_quota
end

#row_countFixnum

The total number of rows in the query result. rowCount is independent of the number of rows returned in the response and the limit request parameter. For example if a query returns 175 rows and includes limit of 50 in the API request, the response will contain rowCount of 175 but only 50 rows. Corresponds to the JSON property rowCount

Returns:

  • (Fixnum)


2285
2286
2287
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2285

def row_count
  @row_count
end

#rowsArray<Google::Apis::AnalyticsdataV1beta::Row>

Rows of dimension value combinations and metric values in the report. Corresponds to the JSON property rows



2290
2291
2292
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2290

def rows
  @rows
end

#totalsArray<Google::Apis::AnalyticsdataV1beta::Row>

If requested, the totaled values of metrics. Corresponds to the JSON property totals



2295
2296
2297
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2295

def totals
  @totals
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2302

def update!(**args)
  @dimension_headers = args[:dimension_headers] if args.key?(:dimension_headers)
  @kind = args[:kind] if args.key?(:kind)
  @maximums = args[:maximums] if args.key?(:maximums)
  @metric_headers = args[:metric_headers] if args.key?(:metric_headers)
  @minimums = args[:minimums] if args.key?(:minimums)
  @property_quota = args[:property_quota] if args.key?(:property_quota)
  @row_count = args[:row_count] if args.key?(:row_count)
  @rows = args[:rows] if args.key?(:rows)
  @totals = args[:totals] if args.key?(:totals)
end