Class: Google::Apis::AnalyticsdataV1beta::RunReportRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsdata_v1beta/classes.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb

Overview

The request to generate a report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunReportRequest

Returns a new instance of RunReportRequest.



2447
2448
2449
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cohort_specGoogle::Apis::AnalyticsdataV1beta::CohortSpec

The specification of cohorts for a cohort report. Cohort reports create a time series of user retention for the cohort. For example, you could select the cohort of users that were acquired in the first week of September and follow that cohort for the next six weeks. Selecting the users acquired in the first week of September cohort is specified in the cohort object. Following that cohort for the next six weeks is specified in the cohortsRange object. For examples, see Cohort Report Examples. The report response could show a weekly time series where say your app has retained 60% of this cohort after three weeks and 25% of this cohort after six weeks. These two percentages can be calculated by the metric cohortActiveUsers/ cohortTotalUsers and will be separate rows in the report. Corresponds to the JSON property cohortSpec



2333
2334
2335
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2333

def cohort_spec
  @cohort_spec
end

#comparisonsArray<Google::Apis::AnalyticsdataV1beta::Comparison>

Optional. The configuration of comparisons requested and displayed. The request only requires a comparisons field in order to receive a comparison column in the response. Corresponds to the JSON property comparisons



2340
2341
2342
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2340

def comparisons
  @comparisons
end

#currency_codeString

A currency code in ISO4217 format, such as "AED", "USD", "JPY". If the field is empty, the report uses the property's default currency. Corresponds to the JSON property currencyCode

Returns:

  • (String)


2346
2347
2348
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2346

def currency_code
  @currency_code
end

#date_rangesArray<Google::Apis::AnalyticsdataV1beta::DateRange>

Date ranges of data to read. If multiple date ranges are requested, each response row will contain a zero based date range index. If two date ranges overlap, the event data for the overlapping days is included in the response rows for both date ranges. In a cohort request, this dateRanges must be unspecified. Corresponds to the JSON property dateRanges



2355
2356
2357
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2355

def date_ranges
  @date_ranges
end

#dimension_filterGoogle::Apis::AnalyticsdataV1beta::FilterExpression

To express dimension or metric filters. The fields in the same FilterExpression need to be either all dimensions or all metrics. Corresponds to the JSON property dimensionFilter



2361
2362
2363
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2361

def dimension_filter
  @dimension_filter
end

#dimensionsArray<Google::Apis::AnalyticsdataV1beta::Dimension>

The dimensions requested and displayed. Corresponds to the JSON property dimensions



2366
2367
2368
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2366

def dimensions
  @dimensions
end

#keep_empty_rowsBoolean Also known as: keep_empty_rows?

If false or unspecified, each row with all metrics equal to 0 will not be returned. If true, these rows will be returned if they are not separately removed by a filter. Regardless of this keep_empty_rows setting, only data recorded by the Google Analytics property can be displayed in a report. For example if a property never logs a purchase event, then a query for the eventName dimension and eventCount metric will not have a row eventName: " purchase" and eventCount: 0. Corresponds to the JSON property keepEmptyRows

Returns:

  • (Boolean)


2377
2378
2379
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2377

def keep_empty_rows
  @keep_empty_rows
end

#limitFixnum

The number of rows to return. If unspecified, 10,000 rows are returned. The API returns a maximum of 250,000 rows per request, no matter how many you ask for. limit must be positive. The API can also return fewer rows than the requested limit, if there aren't as many dimension values as the limit. For instance, there are fewer than 300 possible values for the dimension country, so when reporting on only country, you can't get more than 300 rows, even if you set limit to a higher value. To learn more about this pagination parameter, see Pagination. Corresponds to the JSON property limit

Returns:

  • (Fixnum)


2391
2392
2393
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2391

def limit
  @limit
end

#metric_aggregationsArray<String>

Aggregation of metrics. Aggregated metric values will be shown in rows where the dimension_values are set to "RESERVED_(MetricAggregation)". Aggregates including both comparisons and multiple date ranges will be aggregated based on the date ranges. Corresponds to the JSON property metricAggregations

Returns:

  • (Array<String>)


2399
2400
2401
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2399

def metric_aggregations
  @metric_aggregations
end

#metric_filterGoogle::Apis::AnalyticsdataV1beta::FilterExpression

To express dimension or metric filters. The fields in the same FilterExpression need to be either all dimensions or all metrics. Corresponds to the JSON property metricFilter



2405
2406
2407
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2405

def metric_filter
  @metric_filter
end

#metricsArray<Google::Apis::AnalyticsdataV1beta::Metric>

The metrics requested and displayed. Corresponds to the JSON property metrics



2410
2411
2412
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2410

def metrics
  @metrics
end

#offsetFixnum

The row count of the start row. The first row is counted as row 0. When paging, the first request does not specify offset; or equivalently, sets offset to 0; the first request returns the first limit of rows. The second request sets offset to the limit of the first request; the second request returns the second limit of rows. To learn more about this pagination parameter, see Pagination. Corresponds to the JSON property offset

Returns:

  • (Fixnum)


2421
2422
2423
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2421

def offset
  @offset
end

#order_bysArray<Google::Apis::AnalyticsdataV1beta::OrderBy>

Specifies how rows are ordered in the response. Requests including both comparisons and multiple date ranges will have order bys applied on the comparisons. Corresponds to the JSON property orderBys



2428
2429
2430
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2428

def order_bys
  @order_bys
end

#propertyString

A Google Analytics property identifier whose events are tracked. Specified in the URL path and not the body. To learn more, see where to find your Property ID. Within a batch request, this property should either be unspecified or consistent with the batch-level property. Example: properties/ 1234 Corresponds to the JSON property property

Returns:

  • (String)


2438
2439
2440
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2438

def property
  @property
end

#return_property_quotaBoolean Also known as: return_property_quota?

Toggles whether to return the current state of this Google Analytics property' s quota. Quota is returned in PropertyQuota. Corresponds to the JSON property returnPropertyQuota

Returns:

  • (Boolean)


2444
2445
2446
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2444

def return_property_quota
  @return_property_quota
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2452

def update!(**args)
  @cohort_spec = args[:cohort_spec] if args.key?(:cohort_spec)
  @comparisons = args[:comparisons] if args.key?(:comparisons)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @date_ranges = args[:date_ranges] if args.key?(:date_ranges)
  @dimension_filter = args[:dimension_filter] if args.key?(:dimension_filter)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @keep_empty_rows = args[:keep_empty_rows] if args.key?(:keep_empty_rows)
  @limit = args[:limit] if args.key?(:limit)
  @metric_aggregations = args[:metric_aggregations] if args.key?(:metric_aggregations)
  @metric_filter = args[:metric_filter] if args.key?(:metric_filter)
  @metrics = args[:metrics] if args.key?(:metrics)
  @offset = args[:offset] if args.key?(:offset)
  @order_bys = args[:order_bys] if args.key?(:order_bys)
  @property = args[:property] if args.key?(:property)
  @return_property_quota = args[:return_property_quota] if args.key?(:return_property_quota)
end