Class: Google::Apis::AnalyticsdataV1beta::RunReportResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/analyticsdata_v1beta/classes.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb

Overview

The response report table corresponding to a request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RunReportResponse

Returns a new instance of RunReportResponse.



2537
2538
2539
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2537

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimension_headersArray<Google::Apis::AnalyticsdataV1beta::DimensionHeader>

Describes dimension columns. The number of DimensionHeaders and ordering of DimensionHeaders matches the dimensions present in rows. Corresponds to the JSON property dimensionHeaders



2479
2480
2481
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2479

def dimension_headers
  @dimension_headers
end

#kindString

Identifies what kind of resource this message is. This kind is always the fixed string "analyticsData#runReport". Useful to distinguish between response types in JSON. Corresponds to the JSON property kind

Returns:

  • (String)


2486
2487
2488
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2486

def kind
  @kind
end

#maximumsArray<Google::Apis::AnalyticsdataV1beta::Row>

If requested, the maximum values of metrics. Corresponds to the JSON property maximums



2491
2492
2493
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2491

def maximums
  @maximums
end

#metadataGoogle::Apis::AnalyticsdataV1beta::ResponseMetaData

Response's metadata carrying additional information about the report content. Corresponds to the JSON property metadata



2496
2497
2498
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2496

def 
  @metadata
end

#metric_headersArray<Google::Apis::AnalyticsdataV1beta::MetricHeader>

Describes metric columns. The number of MetricHeaders and ordering of MetricHeaders matches the metrics present in rows. Corresponds to the JSON property metricHeaders



2502
2503
2504
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2502

def metric_headers
  @metric_headers
end

#minimumsArray<Google::Apis::AnalyticsdataV1beta::Row>

If requested, the minimum values of metrics. Corresponds to the JSON property minimums



2507
2508
2509
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2507

def minimums
  @minimums
end

#property_quotaGoogle::Apis::AnalyticsdataV1beta::PropertyQuota

Current state of all quotas for this Analytics Property. If any quota for a property is exhausted, all requests to that property will return Resource Exhausted errors. Corresponds to the JSON property propertyQuota



2514
2515
2516
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2514

def property_quota
  @property_quota
end

#row_countFixnum

The total number of rows in the query result. rowCount is independent of the number of rows returned in the response, the limit request parameter, and the offset request parameter. For example if a query returns 175 rows and includes limit of 50 in the API request, the response will contain rowCount of 175 but only 50 rows. To learn more about this pagination parameter, see Pagination. Corresponds to the JSON property rowCount

Returns:

  • (Fixnum)


2525
2526
2527
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2525

def row_count
  @row_count
end

#rowsArray<Google::Apis::AnalyticsdataV1beta::Row>

Rows of dimension value combinations and metric values in the report. Corresponds to the JSON property rows



2530
2531
2532
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2530

def rows
  @rows
end

#totalsArray<Google::Apis::AnalyticsdataV1beta::Row>

If requested, the totaled values of metrics. Corresponds to the JSON property totals



2535
2536
2537
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2535

def totals
  @totals
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2542

def update!(**args)
  @dimension_headers = args[:dimension_headers] if args.key?(:dimension_headers)
  @kind = args[:kind] if args.key?(:kind)
  @maximums = args[:maximums] if args.key?(:maximums)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metric_headers = args[:metric_headers] if args.key?(:metric_headers)
  @minimums = args[:minimums] if args.key?(:minimums)
  @property_quota = args[:property_quota] if args.key?(:property_quota)
  @row_count = args[:row_count] if args.key?(:row_count)
  @rows = args[:rows] if args.key?(:rows)
  @totals = args[:totals] if args.key?(:totals)
end