Class: Google::Apis::AnalyticsdataV1beta::OrderBy
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticsdataV1beta::OrderBy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticsdata_v1beta/classes.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb
Overview
Order bys define how rows will be sorted in the response. For example, ordering rows by descending event count is one ordering, and ordering rows by the event name string is a different ordering.
Instance Attribute Summary collapse
-
#desc ⇒ Boolean
(also: #desc?)
If true, sorts by descending order.
-
#dimension ⇒ Google::Apis::AnalyticsdataV1beta::DimensionOrderBy
Sorts by dimension values.
-
#metric ⇒ Google::Apis::AnalyticsdataV1beta::MetricOrderBy
Sorts by metric values.
-
#pivot ⇒ Google::Apis::AnalyticsdataV1beta::PivotOrderBy
Sorts by a pivot column group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OrderBy
constructor
A new instance of OrderBy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OrderBy
Returns a new instance of OrderBy.
1506 1507 1508 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1506 def initialize(**args) update!(**args) end |
Instance Attribute Details
#desc ⇒ Boolean Also known as: desc?
If true, sorts by descending order.
Corresponds to the JSON property desc
1488 1489 1490 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1488 def desc @desc end |
#dimension ⇒ Google::Apis::AnalyticsdataV1beta::DimensionOrderBy
Sorts by dimension values.
Corresponds to the JSON property dimension
1494 1495 1496 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1494 def dimension @dimension end |
#metric ⇒ Google::Apis::AnalyticsdataV1beta::MetricOrderBy
Sorts by metric values.
Corresponds to the JSON property metric
1499 1500 1501 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1499 def metric @metric end |
#pivot ⇒ Google::Apis::AnalyticsdataV1beta::PivotOrderBy
Sorts by a pivot column group.
Corresponds to the JSON property pivot
1504 1505 1506 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1504 def pivot @pivot end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1511 1512 1513 1514 1515 1516 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 1511 def update!(**args) @desc = args[:desc] if args.key?(:desc) @dimension = args[:dimension] if args.key?(:dimension) @metric = args[:metric] if args.key?(:metric) @pivot = args[:pivot] if args.key?(:pivot) end |