Class: Google::Apis::AnalyticsdataV1beta::RunRealtimeReportRequest
- Inherits:
-
Object
- Object
- Google::Apis::AnalyticsdataV1beta::RunRealtimeReportRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/analyticsdata_v1beta/classes.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb,
lib/google/apis/analyticsdata_v1beta/representations.rb
Overview
The request to generate a realtime report.
Instance Attribute Summary collapse
-
#dimension_filter ⇒ Google::Apis::AnalyticsdataV1beta::FilterExpression
To express dimension or metric filters.
-
#dimensions ⇒ Array<Google::Apis::AnalyticsdataV1beta::Dimension>
The dimensions requested and displayed.
-
#limit ⇒ Fixnum
The number of rows to return.
-
#metric_aggregations ⇒ Array<String>
Aggregation of metrics.
-
#metric_filter ⇒ Google::Apis::AnalyticsdataV1beta::FilterExpression
To express dimension or metric filters.
-
#metrics ⇒ Array<Google::Apis::AnalyticsdataV1beta::Metric>
The metrics requested and displayed.
-
#minute_ranges ⇒ Array<Google::Apis::AnalyticsdataV1beta::MinuteRange>
The minute ranges of event data to read.
-
#order_bys ⇒ Array<Google::Apis::AnalyticsdataV1beta::OrderBy>
Specifies how rows are ordered in the response.
-
#return_property_quota ⇒ Boolean
(also: #return_property_quota?)
Toggles whether to return the current state of this Google Analytics property' s Realtime quota.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RunRealtimeReportRequest
constructor
A new instance of RunRealtimeReportRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RunRealtimeReportRequest
Returns a new instance of RunRealtimeReportRequest.
2221 2222 2223 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2221 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimension_filter ⇒ Google::Apis::AnalyticsdataV1beta::FilterExpression
To express dimension or metric filters. The fields in the same
FilterExpression need to be either all dimensions or all metrics.
Corresponds to the JSON property dimensionFilter
2165 2166 2167 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2165 def dimension_filter @dimension_filter end |
#dimensions ⇒ Array<Google::Apis::AnalyticsdataV1beta::Dimension>
The dimensions requested and displayed.
Corresponds to the JSON property dimensions
2170 2171 2172 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2170 def dimensions @dimensions end |
#limit ⇒ Fixnum
The number of rows to return. If unspecified, 10,000 rows are returned. The
API returns a maximum of 250,000 rows per request, no matter how many you ask
for. limit must be positive. The API can also return fewer rows than the
requested limit, if there aren't as many dimension values as the limit.
For instance, there are fewer than 300 possible values for the dimension
country, so when reporting on only country, you can't get more than 300
rows, even if you set limit to a higher value.
Corresponds to the JSON property limit
2181 2182 2183 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2181 def limit @limit end |
#metric_aggregations ⇒ Array<String>
Aggregation of metrics. Aggregated metric values will be shown in rows where
the dimension_values are set to "RESERVED_(MetricAggregation)".
Corresponds to the JSON property metricAggregations
2187 2188 2189 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2187 def metric_aggregations @metric_aggregations end |
#metric_filter ⇒ Google::Apis::AnalyticsdataV1beta::FilterExpression
To express dimension or metric filters. The fields in the same
FilterExpression need to be either all dimensions or all metrics.
Corresponds to the JSON property metricFilter
2193 2194 2195 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2193 def metric_filter @metric_filter end |
#metrics ⇒ Array<Google::Apis::AnalyticsdataV1beta::Metric>
The metrics requested and displayed.
Corresponds to the JSON property metrics
2198 2199 2200 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2198 def metrics @metrics end |
#minute_ranges ⇒ Array<Google::Apis::AnalyticsdataV1beta::MinuteRange>
The minute ranges of event data to read. If unspecified, one minute range for
the last 30 minutes will be used. If multiple minute ranges are requested,
each response row will contain a zero based minute range index. If two minute
ranges overlap, the event data for the overlapping minutes is included in the
response rows for both minute ranges.
Corresponds to the JSON property minuteRanges
2207 2208 2209 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2207 def minute_ranges @minute_ranges end |
#order_bys ⇒ Array<Google::Apis::AnalyticsdataV1beta::OrderBy>
Specifies how rows are ordered in the response.
Corresponds to the JSON property orderBys
2212 2213 2214 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2212 def order_bys @order_bys end |
#return_property_quota ⇒ Boolean Also known as: return_property_quota?
Toggles whether to return the current state of this Google Analytics property'
s Realtime quota. Quota is returned in PropertyQuota.
Corresponds to the JSON property returnPropertyQuota
2218 2219 2220 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2218 def return_property_quota @return_property_quota end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 |
# File 'lib/google/apis/analyticsdata_v1beta/classes.rb', line 2226 def update!(**args) @dimension_filter = args[:dimension_filter] if args.key?(:dimension_filter) @dimensions = args[:dimensions] if args.key?(:dimensions) @limit = args[:limit] if args.key?(:limit) @metric_aggregations = args[:metric_aggregations] if args.key?(:metric_aggregations) @metric_filter = args[:metric_filter] if args.key?(:metric_filter) @metrics = args[:metrics] if args.key?(:metrics) @minute_ranges = args[:minute_ranges] if args.key?(:minute_ranges) @order_bys = args[:order_bys] if args.key?(:order_bys) @return_property_quota = args[:return_property_quota] if args.key?(:return_property_quota) end |